@@ -1,16 +1,16 @@
-import board
-import busio
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
 
-# I2C setup
+import board
 from adafruit_cap1188.i2c import CAP1188_I2C
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
 cap = CAP1188_I2C(i2c)
 
 # SPI setup
 # from digitalio import DigitalInOut, Direction
 # from adafruit_cap1188.spi import CAP1188_SPI
-# spi = busio.SPI(board.SCK, board.MOSI, board.MISO)
+# spi = board.SPI()
 # cs = DigitalInOut(board.D5)
 # cap = CAP1188_SPI(spi, cs)
 
